summaryrefslogtreecommitdiffstats
path: root/nova/tests
diff options
context:
space:
mode:
authorPádraig Brady <pbrady@redhat.com>2013-01-16 17:52:38 +0000
committerPádraig Brady <pbrady@redhat.com>2013-01-21 23:14:13 +0000
commitf379db545cf63f4ec854df748a1b7d256dc9bad4 (patch)
treef09f8adf9db9aad67d5ecd862ce7be2f4af40b41 /nova/tests
parenta4d608fa33b328d7ed77c7f9c40ffbb43c0ade6b (diff)
fix misspellings in logs, comments and tests
Flagged with: https://github.com/lyda/misspell-check Run with: git ls-files | misspellings -f - Fixes bug: 1100083 Change-Id: Icf1f844fea8ad0a1101d1dc64b9a126608e9536e
Diffstat (limited to 'nova/tests')
-rw-r--r--nova/tests/api/openstack/compute/contrib/test_admin_actions_with_cells.py10
-rw-r--r--nova/tests/api/openstack/compute/contrib/test_services.py4
-rw-r--r--nova/tests/api/openstack/compute/test_limits.py2
-rw-r--r--nova/tests/compute/test_compute.py8
-rw-r--r--nova/tests/image/test_s3.py4
-rw-r--r--nova/tests/test_imagecache.py4
-rw-r--r--nova/tests/test_libvirt.py3
-rw-r--r--nova/tests/test_migrations.py4
-rw-r--r--nova/tests/test_pipelib.py8
9 files changed, 23 insertions, 24 deletions
diff --git a/nova/tests/api/openstack/compute/contrib/test_services.py b/nova/tests/api/openstack/compute/contrib/test_services.py
index 1bd47b67a..3a6e5db7c 100644
--- a/nova/tests/api/openstack/compute/contrib/test_services.py
+++ b/nova/tests/api/openstack/compute/contrib/test_services.py
@@ -60,7 +60,7 @@ class FakeRequest(object):
GET = {}
-class FakeRequestWithSevice(object):
+class FakeRequestWithService(object):
environ = {"nova.context": context.get_admin_context()}
GET = {"service": "nova-compute"}
@@ -160,7 +160,7 @@ class ServicesTest(test.TestCase):
self.assertEqual(res_dict, response)
def test_services_list_with_service(self):
- req = FakeRequestWithSevice()
+ req = FakeRequestWithService()
res_dict = self.controller.index(req)
response = {'services': [{'binary': 'nova-compute', 'host': 'host1',
diff --git a/nova/tests/api/openstack/compute/test_limits.py b/nova/tests/api/openstack/compute/test_limits.py
index f0f2f02d5..375355a70 100644
--- a/nova/tests/api/openstack/compute/test_limits.py
+++ b/nova/tests/api/openstack/compute/test_limits.py
@@ -618,7 +618,7 @@ class WsgiLimiterTest(BaseLimitTestSuite):
self.app = limits.WsgiLimiter(TEST_LIMITS)
def _request_data(self, verb, path):
- """Get data decribing a limit request verb/path."""
+ """Get data describing a limit request verb/path."""
return jsonutils.dumps({"verb": verb, "path": path})
def _request(self, verb, url, username=None):
diff --git a/nova/tests/compute/test_compute.py b/nova/tests/compute/test_compute.py
index 092fd940a..4a51ebad2 100644
--- a/nova/tests/compute/test_compute.py
+++ b/nova/tests/compute/test_compute.py
@@ -2961,7 +2961,7 @@ class ComputeTestCase(BaseTestCase):
call_info['expected_instance'] = instances[0]
self.compute._heal_instance_info_cache(ctxt)
self.assertEqual(call_info['get_all_by_host'], 2)
- # Stays the same, beacuse the instance came from the DB
+ # Stays the same, because the instance came from the DB
self.assertEqual(call_info['get_by_uuid'], 3)
self.assertEqual(call_info['get_nw_info'], 4)
@@ -5255,14 +5255,14 @@ class ComputeAPITestCase(BaseTestCase):
self.assertTrue(instance3['uuid'] in instance_uuids)
self.assertTrue(instance4['uuid'] in instance_uuids)
- # multiple criterias as a dict
+ # multiple criteria as a dict
instances = self.compute_api.get_all(c,
search_opts={'metadata': {'key3': 'value3',
'key4': 'value4'}})
self.assertEqual(len(instances), 1)
self.assertEqual(instances[0]['uuid'], instance4['uuid'])
- # multiple criterias as a list
+ # multiple criteria as a list
instances = self.compute_api.get_all(c,
search_opts={'metadata': [{'key4': 'value4'},
{'key3': 'value3'}]})
@@ -6430,7 +6430,7 @@ class DisabledInstanceTypesTestCase(BaseTestCase):
"""
Some instance-types are marked 'disabled' which means that they will not
show up in customer-facing listings. We do, however, want those
- instance-types to be availble for emergency migrations and for rebuilding
+ instance-types to be available for emergency migrations and for rebuilding
of existing instances.
One legitimate use of the 'disabled' field would be when phasing out a
diff --git a/nova/tests/image/test_s3.py b/nova/tests/image/test_s3.py
index 4f8790cc7..0afe397a2 100644
--- a/nova/tests/image/test_s3.py
+++ b/nova/tests/image/test_s3.py
@@ -129,7 +129,7 @@ class TestS3ImageService(test.TestCase):
'snapshot_id': 'snap-12345678',
'delete_on_termination': True},
{'device_name': '/dev/sda2',
- 'virutal_name': 'ephemeral0'},
+ 'virtual_name': 'ephemeral0'},
{'device_name': '/dev/sdb0',
'no_device': True}]}}
_manifest, image, image_uuid = self.image_service._s3_parse_manifest(
@@ -156,7 +156,7 @@ class TestS3ImageService(test.TestCase):
'snapshot_id': 'snap-12345678',
'delete_on_termination': True},
{'device_name': '/dev/sda2',
- 'virutal_name': 'ephemeral0'},
+ 'virtual_name': 'ephemeral0'},
{'device_name': '/dev/sdb0',
'no_device': True}]
self.assertEqual(block_device_mapping, expected_bdm)
diff --git a/nova/tests/test_libvirt.py b/nova/tests/test_libvirt.py
index 83b7f43bc..2e1a1729a 100644
--- a/nova/tests/test_libvirt.py
+++ b/nova/tests/test_libvirt.py
@@ -570,7 +570,6 @@ class LibvirtConnTestCase(test.TestCase):
self.context = context.get_admin_context()
self.flags(instances_path='')
self.flags(libvirt_snapshots_directory='')
- self.call_libvirt_dependant_setup = False
self.useFixture(fixtures.MonkeyPatch(
'nova.virt.libvirt.driver.libvirt_utils',
fake_libvirt_utils))
@@ -3100,7 +3099,7 @@ class LibvirtConnTestCase(test.TestCase):
self.stubs.Set(conn, 'get_info', fake_get_info)
instance = {"name": "instancename", "id": "instanceid",
"uuid": "875a8070-d0b9-4949-8b31-104d125c9a64"}
- # NOTE(vish): verifies destory doesn't raise if the instance disappears
+ # NOTE(vish): verifies destroy doesn't raise if the instance disappears
conn._destroy(instance)
def test_available_least_handles_missing(self):
diff --git a/nova/tests/test_migrations.py b/nova/tests/test_migrations.py
index abd04a641..0f8f8aed7 100644
--- a/nova/tests/test_migrations.py
+++ b/nova/tests/test_migrations.py
@@ -47,7 +47,7 @@ def _get_connect_string(backend,
passwd="openstack_citest",
database="openstack_citest"):
"""
- Try to get a connection with a very specfic set of values, if we get
+ Try to get a connection with a very specific set of values, if we get
these then we'll run the tests, otherwise they are skipped
"""
if backend == "postgres":
@@ -195,7 +195,7 @@ class TestMigrations(test.TestCase):
"~/.pgpass && chmod 0600 ~/.pgpass" % locals())
execute_cmd(createpgpass)
# note(boris-42): We must create and drop database, we can't
- # drop database wich we have connected to, so for such
+ # drop database which we have connected to, so for such
# operations there is a special database template1.
sqlcmd = ("psql -w -U %(user)s -h %(host)s -c"
" '%(sql)s' -d template1")
diff --git a/nova/tests/test_pipelib.py b/nova/tests/test_pipelib.py
index 85c2ca2cd..5cd715552 100644
--- a/nova/tests/test_pipelib.py
+++ b/nova/tests/test_pipelib.py
@@ -51,11 +51,11 @@ class PipelibTest(test.TestCase):
def test_setup_security_group(self):
group_name = "%s%s" % (self.project, CONF.vpn_key_suffix)
- # First attemp, does not exist (thus its created)
+ # First attempt, does not exist (thus its created)
res1_group = self.cloudpipe.setup_security_group(self.context)
self.assertEqual(res1_group, group_name)
- # Second attem, it exists in the DB
+ # Second attempt, it exists in the DB
res2_group = self.cloudpipe.setup_security_group(self.context)
self.assertEqual(res1_group, res2_group)
@@ -64,10 +64,10 @@ class PipelibTest(test.TestCase):
with utils.tempdir() as tmpdir:
self.flags(keys_path=tmpdir)
- # First attemp, key does not exist (thus it is generated)
+ # First attempt, key does not exist (thus it is generated)
res1_key = self.cloudpipe.setup_key_pair(self.context)
self.assertEqual(res1_key, key_name)
- # Second attem, it exists in the DB
+ # Second attempt, it exists in the DB
res2_key = self.cloudpipe.setup_key_pair(self.context)
self.assertEqual(res2_key, res1_key)
diff --git a/nova/tests/api/openstack/compute/contrib/test_admin_actions_with_cells.py b/nova/tests/api/openstack/compute/contrib/test_admin_actions_with_cells.py
index b8f4e6398..4e577e1f5 100644
--- a/nova/tests/api/openstack/compute/contrib/test_admin_actions_with_cells.py
+++ b/nova/tests/api/openstack/compute/contrib/test_admin_actions_with_cells.py
@@ -54,10 +54,10 @@ class CellsAdminAPITestCase(test.TestCase):
def fake_cast_to_cells(context, instance, method, *args, **kwargs):
"""
- Makes sure that the cells recieve the cast to update
+ Makes sure that the cells receive the cast to update
the cell state
"""
- self.cells_recieved_kwargs.update(kwargs)
+ self.cells_received_kwargs.update(kwargs)
self.admin_api = admin_actions.AdminActionsController()
self.admin_api.compute_api = compute_cells_api.ComputeCellsAPI()
@@ -76,14 +76,14 @@ class CellsAdminAPITestCase(test.TestCase):
self.uuid = uuidutils.generate_uuid()
url = '/fake/servers/%s/action' % self.uuid
self.request = fakes.HTTPRequest.blank(url)
- self.cells_recieved_kwargs = {}
+ self.cells_received_kwargs = {}
def test_reset_active(self):
body = {"os-resetState": {"state": "error"}}
result = self.admin_api._reset_state(self.request, 'inst_id', body)
self.assertEqual(result.status_int, 202)
- # Make sure the cells recieved the update
- self.assertEqual(self.cells_recieved_kwargs,
+ # Make sure the cells received the update
+ self.assertEqual(self.cells_received_kwargs,
dict(vm_state=vm_states.ERROR,
task_state=None))
diff --git a/nova/tests/test_imagecache.py b/nova/tests/test_imagecache.py
index eaf244c56..8142312b9 100644
--- a/nova/tests/test_imagecache.py
+++ b/nova/tests/test_imagecache.py
@@ -721,7 +721,7 @@ class ImageCacheManagerTestCase(test.TestCase):
def fq_path(path):
return os.path.join('/instance_path/_base/', path)
# Fake base directory existance
orig_exists = os.path.exists
def exists(path):
@@ -747,7 +747,7 @@ class ImageCacheManagerTestCase(test.TestCase):
'/instance_path/_base/%s_sm' % hashed_42]:
return False
- self.fail('Unexpected path existance check: %s' % path)
+ self.fail('Unexpected path existence check: %s' % path)
self.stubs.Set(os.path, 'exists', lambda x: exists(x))
@@ -721,7 +721,7 @@ class ImageCacheManagerTestCase(test.TestCase):
def fq_path(path):
return os.path.join('/instance_path/_base/', path)
- # Fake base directory existance
+ # Fake base directory existence
orig_exists = os.path.exists
def exists(path):